You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by pf...@apache.org on 2016/05/22 01:05:22 UTC

svn commit: r1745006 [9/9] - in /openoffice/trunk/main: ./ accessibility/inc/accessibility/standard/ autodoc/inc/ary/idl/ avmedia/source/framework/ basctl/source/basicide/ basctl/source/inc/ basegfx/inc/basegfx/color/ basegfx/inc/basegfx/polygon/ baseg...

Modified: openoffice/trunk/main/sfx2/source/view/viewprn.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/view/viewprn.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/view/viewprn.cxx (original)
+++ openoffice/trunk/main/sfx2/source/view/viewprn.cxx Sun May 22 01:05:14 2016
@@ -271,7 +271,7 @@ void SfxPrinterController::printPage( in
         }
         catch( lang::IllegalArgumentException& )
         {
-            // don't care enough about nonexistant page here
+            // don't care enough about nonexistent page here
             // to provoke a crash
         }
     }

Modified: openoffice/trunk/main/shell/inc/internal/registry.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/shell/inc/internal/registry.hxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/shell/inc/internal/registry.hxx (original)
+++ openoffice/trunk/main/shell/inc/internal/registry.hxx Sun May 22 01:05:14 2016
@@ -49,7 +49,7 @@ bool SetRegistryKey(HKEY RootKey, const
 bool DeleteRegistryKey(HKEY RootKey, const char* KeyName);
 
 /** May be used to determine if the specified registry key has subkeys
-	The function returns true on success else if an error occures false
+	The function returns true on success else if an error occurs false
 */
 bool HasSubkeysRegistryKey(HKEY RootKey, const char* KeyName, bool& bResult);
 

Modified: openoffice/trunk/main/shell/inc/internal/zipfile.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/shell/inc/internal/zipfile.hxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/shell/inc/internal/zipfile.hxx (original)
+++ openoffice/trunk/main/shell/inc/internal/zipfile.hxx Sun May 22 01:05:14 2016
@@ -135,7 +135,7 @@ public:
 	*/
 	DirectoryPtr_t GetDirectory() const;
 
-	/** Convinience query function may even realized with 
+	/** Convenience query function may even realized with 
 		iterating over a ZipFileDirectory returned by
 		GetDirectory
 	*/

Modified: openoffice/trunk/main/shell/source/all/zipfile/zipfile.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/shell/source/all/zipfile/zipfile.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/shell/source/all/zipfile/zipfile.cxx (original)
+++ openoffice/trunk/main/shell/source/all/zipfile/zipfile.cxx Sun May 22 01:05:14 2016
@@ -207,7 +207,7 @@ ZipFile::DirectoryPtr_t ZipFile::GetDire
 	return dir;
 }
 
-/** Convinience query function may even realized with 
+/** Convenience query function may even realized with 
 	iterating over a ZipFileDirectory returned by
 	GetDirectory */
 bool ZipFile::HasContent(const std::string& ContentName) const

Modified: openoffice/trunk/main/shell/source/win32/shlxthandler/infotips/infotips.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/shell/source/win32/shlxthandler/infotips/infotips.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/shell/source/win32/shlxthandler/infotips/infotips.cxx (original)
+++ openoffice/trunk/main/shell/source/win32/shlxthandler/infotips/infotips.cxx Sun May 22 01:05:14 2016
@@ -269,7 +269,7 @@ HRESULT STDMETHODCALLTYPE CInfoTip::GetI
             msg += meta_info_accessor.getTagData( META_INFO_DESCRIPTION );
         }
 
-        //display midified time formated into locale representation.
+        //display midified time formatted into locale representation.
         if ( iso8601_date_to_local_date(meta_info_accessor.getTagData(META_INFO_MODIFIED )).length() > 0)
         {
 			if ( msg != EMPTY_STRING )

Modified: openoffice/trunk/main/shell/source/win32/shlxthandler/util/registry.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/shell/source/win32/shlxthandler/util/registry.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/shell/source/win32/shlxthandler/util/registry.cxx (original)
+++ openoffice/trunk/main/shell/source/win32/shlxthandler/util/registry.cxx Sun May 22 01:05:14 2016
@@ -137,7 +137,7 @@ bool DeleteRegistryKey(HKEY RootKey, con
 }
 
 /** May be used to determine if the specified registry key has subkeys
-	The function returns true on success else if an error occures false
+	The function returns true on success else if an error occurs false
 */
 bool HasSubkeysRegistryKey(HKEY RootKey, const char* KeyName, /* out */ bool& bResult)
 {

Modified: openoffice/trunk/main/slideshow/source/engine/transitions/slidetransitionfactory.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/slideshow/source/engine/transitions/slidetransitionfactory.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/slideshow/source/engine/transitions/slidetransitionfactory.cxx (original)
+++ openoffice/trunk/main/slideshow/source/engine/transitions/slidetransitionfactory.cxx Sun May 22 01:05:14 2016
@@ -481,7 +481,7 @@ class MovingSlideChange : public SlideCh
     
 public:
     /** Create a new SlideChanger, for the given entering slide
-        bitmaps, which performes a moving slide change effect
+        bitmaps, which performs a moving slide change effect
         
         @param rLeavingDirection
         Direction vector. The move is performed along this

Modified: openoffice/trunk/main/solenv/bin/deliver.pl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/deliver.pl?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/deliver.pl (original)
+++ openoffice/trunk/main/solenv/bin/deliver.pl Sun May 22 01:05:14 2016
@@ -200,7 +200,7 @@ sub do_dos
         print "DOS: $command\n";
     }
     else {
-        # HACK: remove MACOSX stuff which is wrongly labled with dos
+        # HACK: remove MACOSX stuff which is wrongly labeled with dos
         # better: fix broken d.lst
         return if ( $command =~ /MACOSX/ );
         $command =~ s#/#\\#g if $^O eq 'MSWin32';

Modified: openoffice/trunk/main/solenv/bin/modules/installer/patch/FileOperations.pm
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/solenv/bin/modules/installer/patch/FileOperations.pm?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/solenv/bin/modules/installer/patch/FileOperations.pm (original)
+++ openoffice/trunk/main/solenv/bin/modules/installer/patch/FileOperations.pm Sun May 22 01:05:14 2016
@@ -184,7 +184,7 @@ sub Check ($)
             }
             if ( -f $destination_filename && ! -w $destination_filename)
             {
-                # Destination file aleady exists but can not be replaced.
+                # Destination file already exists but can not be replaced.
                 push @error_messages, sprintf("compress destination file %s exists but can not be replaced", $destination_filename);
             }
         }

Modified: openoffice/trunk/main/testgraphical/ui/java/ConvwatchGUIProject/src/ConvwatchGUI.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/testgraphical/ui/java/ConvwatchGUIProject/src/ConvwatchGUI.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/testgraphical/ui/java/ConvwatchGUIProject/src/ConvwatchGUI.java (original)
+++ openoffice/trunk/main/testgraphical/ui/java/ConvwatchGUIProject/src/ConvwatchGUI.java Sun May 22 01:05:14 2016
@@ -466,7 +466,7 @@ public class ConvwatchGUI extends javax.
             h = _aLabel.getHeight();
         }
 
-        // dont access here anything to "Event Swing Thread"
+        // don't access here anything to "Event Swing Thread"
         @Override
         public ImageIcon doInBackground()
         {

Modified: openoffice/trunk/main/ucb/source/ucp/odma/odma.h
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/ucb/source/ucp/odma/odma.h?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/ucb/source/ucp/odma/odma.h (original)
+++ openoffice/trunk/main/ucb/source/ucp/odma/odma.h Sun May 22 01:05:14 2016
@@ -1,4 +1,4 @@
-/* odma.h - Definitions, prototypes, etc. for Open Document Managment API
+/* odma.h - Definitions, prototypes, etc. for Open Document Management API
 	(ODMA) version 2.0.
                OPEN DOCUMENT MANAGEMENT API LICENSE 1.0
                      
@@ -119,7 +119,7 @@ typedef int ODMSTATUS;
 #define ODM_E_FAIL			1		/* Unspecified failure */
 #define ODM_E_CANCEL		2		/* Action was cancelled at user's request */
 #define ODM_E_NODMS			3		/* DMS not registered */
-#define ODM_E_CANTINIT		4		/* DMS failed to initalize */
+#define ODM_E_CANTINIT		4		/* DMS failed to initialize */
 #define ODM_E_VERSION		5		/* DMS doesn't support the requested 
 									           version of ODMA */
 #define ODM_E_APPSELECT		6        /* User has indicated that he wants to use 

Modified: openoffice/trunk/main/ucb/source/ucp/tdoc/tdoc_content.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/ucb/source/ucp/tdoc/tdoc_content.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/ucb/source/ucp/tdoc/tdoc_content.cxx (original)
+++ openoffice/trunk/main/ucb/source/ucp/tdoc/tdoc_content.cxx Sun May 22 01:05:14 2016
@@ -2035,7 +2035,7 @@ void Content::transfer(
 
     if ( ( rInfo.SourceURL.getLength() < TDOC_URL_SCHEME_LENGTH + 2 ) )
     {
-        // Invaild length (to short).
+        // Invalid length (to short).
         ucbhelper::cancelCommandExecution(
             uno::makeAny( ucb::InteractiveBadTransferURLException(
                             rtl::OUString(),

Modified: openoffice/trunk/main/ucb/source/ucp/tdoc/tdoc_uri.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/ucb/source/ucp/tdoc/tdoc_uri.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/ucb/source/ucp/tdoc/tdoc_uri.cxx (original)
+++ openoffice/trunk/main/ucb/source/ucp/tdoc/tdoc_uri.cxx Sun May 22 01:05:14 2016
@@ -55,7 +55,7 @@ void Uri::init() const
         // Check for proper length: must be at least length of <sheme>:/
         if ( ( m_aUri.getLength() < TDOC_URL_SCHEME_LENGTH + 2 ) )
         {
-            // Invaild length (to short).
+            // Invalid length (to short).
             return;
         }
 
@@ -65,7 +65,7 @@ void Uri::init() const
         if ( !aScheme.equalsAsciiL(
                 RTL_CONSTASCII_STRINGPARAM( TDOC_URL_SCHEME ) ) )
         {
-            // Invaild scheme.
+            // Invalid scheme.
             return;
         }
 
@@ -75,14 +75,14 @@ void Uri::init() const
         if ( m_aUri.getStr()[ TDOC_URL_SCHEME_LENGTH ]
                 != sal_Unicode( ':' ) )
         {
-            // Invaild (no ':' after <scheme>).
+            // Invalid (no ':' after <scheme>).
             return;
         }
 
         if ( m_aUri.getStr()[ TDOC_URL_SCHEME_LENGTH + 1 ]
                 != sal_Unicode( '/' ) )
         {
-            // Invaild (no '/' after <scheme>:).
+            // Invalid (no '/' after <scheme>:).
             return;
         }
 

Modified: openoffice/trunk/main/ucb/source/ucp/webdav/SerfSession.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/ucb/source/ucp/webdav/SerfSession.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/ucb/source/ucp/webdav/SerfSession.cxx (original)
+++ openoffice/trunk/main/ucb/source/ucp/webdav/SerfSession.cxx Sun May 22 01:05:14 2016
@@ -1404,7 +1404,7 @@ bool containsLocktoken( const uno::Seque
 
 // -------------------------------------------------------------------
 // This method doesn't seem to be used.
-// In any case the default behavior is to ask a lock whith a life of 3 minutes
+// In any case the default behavior is to ask a lock with a life of 3 minutes
 // it will then be refreshed automatically (see SerfLockStore class)
 // In case of AOO crash the lock will expire by itself
 bool SerfSession::removeExpiredLocktoken( const rtl::OUString & /*inURL*/,

Modified: openoffice/trunk/main/ucbhelper/inc/ucbhelper/interactionrequest.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/ucbhelper/inc/ucbhelper/interactionrequest.hxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/ucbhelper/inc/ucbhelper/interactionrequest.hxx (original)
+++ openoffice/trunk/main/ucbhelper/inc/ucbhelper/interactionrequest.hxx Sun May 22 01:05:14 2016
@@ -405,7 +405,7 @@ public:
       *        authentication-remember-mode for accounts preferred by the
       *        requesting client.
       * @param bCanUseSystemCredentials indicates whether issuer of the
-      *        authetication request can obtain and use system credentials
+      *        authentication request can obtain and use system credentials
       *        for authentication.
       * @param bDefaultUseSystemCredentials specifies the default system
       *        credentials usage preferred by the requesting client

Modified: openoffice/trunk/main/ucbhelper/inc/ucbhelper/resultset.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/ucbhelper/inc/ucbhelper/resultset.hxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/ucbhelper/inc/ucbhelper/resultset.hxx (original)
+++ openoffice/trunk/main/ucbhelper/inc/ucbhelper/resultset.hxx Sun May 22 01:05:14 2016
@@ -558,7 +558,7 @@ public:
 	 * Note: An exception thrown to indicate an error must always be thrown
 	 * by the thread that created the data supplier. If the supplier collects
 	 * data asynchronously ( i.e. in a separate thread ) and an error
-	 * occures, throwing of the appropriate exception must be deferred
+	 * occurs, throwing of the appropriate exception must be deferred
 	 * until validate() is called by the ResultSet implementation from
 	 * inside the main thread.
 	 * In case data are obtained synchronously, the ResultSetException can

Modified: openoffice/trunk/main/ucbhelper/inc/ucbhelper/resultsethelper.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/ucbhelper/inc/ucbhelper/resultsethelper.hxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/ucbhelper/inc/ucbhelper/resultsethelper.hxx (original)
+++ openoffice/trunk/main/ucbhelper/inc/ucbhelper/resultsethelper.hxx Sun May 22 01:05:14 2016
@@ -123,7 +123,7 @@ private:
 
 public:
 	/**
-	  * Construtor.
+	  * Constructor.
 	  *
 	  * @param rxSMgr is a Service Manager.
 	  */
@@ -132,7 +132,7 @@ public:
 				com::sun::star::lang::XMultiServiceFactory >& rxSMgr );
 
 	/**
-	  * Construtor.
+	  * Constructor.
 	  *
 	  * @param rxSMgr is a Service Manager.
 	  * @param rCommand is the parameter for the open command that produces

Modified: openoffice/trunk/main/unotools/source/config/configitem.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/unotools/source/config/configitem.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/unotools/source/config/dynamicmenuoptions.cxx (original)
+++ openoffice/trunk/main/unotools/source/config/dynamicmenuoptions.cxx Sun May 22 01:05:14 2016
@@ -138,7 +138,7 @@ class SvtDynMenu
         //---------------------------------------------------------------------------------------------------------
         // append user specific menu entry
         // We must find unique name for it by using special prefix
-        // and next count of user setted entries!
+        // and next count of user set entries!
         // Look for double menu entries here too ... may be some seperator items are supeflous ...
         void AppendUserEntry( SvtDynMenuEntry& rEntry )
         {

Modified: openoffice/trunk/main/unotools/source/config/startoptions.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/unotools/source/config/startoptions.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/unotools/source/config/startoptions.cxx (original)
+++ openoffice/trunk/main/unotools/source/config/startoptions.cxx Sun May 22 01:05:14 2016
@@ -128,7 +128,7 @@ class SvtStartOptions_Impl : public Conf
 
 		/*-****************************************************************************************************//**
 			@short		access method to get internal values
-			@descr		These method give us a chance to regulate acces to ouer internal values.
+			@descr		These method give us a chance to regulate access to ouer internal values.
 						It's not used in the moment - but it's possible for the feature!
 
 			@seealso	-
--- openoffice/trunk/main/unotools/source/config/configitem.cxx (original)
+++ openoffice/trunk/main/unotools/source/config/configitem.cxx Sun May 22 01:05:14 2016
@@ -799,8 +799,8 @@ void lcl_normalizeLocalNames(Sequence< O
                 break;
             }
         }
-        OSL_ENSURE(false, "Cannot create absolute pathes: missing interface");
-        // make local pathes instaed
+        OSL_ENSURE(false, "Cannot create absolute paths: missing interface");
+        // make local paths instaed
 
     case CONFIG_NAME_LOCAL_PATH:
         {

Modified: openoffice/trunk/main/unotools/source/config/configpathes.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/unotools/source/config/configpathes.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/unotools/source/config/configpathes.cxx (original)
+++ openoffice/trunk/main/unotools/source/config/configpathes.cxx Sun May 22 01:05:14 2016
@@ -121,7 +121,7 @@ sal_Bool splitLastFromConfigurationPath(
         {
             nPos =  _sInPath.lastIndexOf('/',nPos);
         }
-        else // defined behavior for invalid pathes
+        else // defined behavior for invalid paths
         {
             nStart = 0, nEnd = _sInPath.getLength();
             nPos = -1;
@@ -202,7 +202,7 @@ sal_Int32 lcl_findPrefixEnd(OUString con
     sal_Int32 nPrefixLength = _sPrefixPath.getLength();
 
     OSL_ENSURE(nPrefixLength == 0 || _sPrefixPath[nPrefixLength-1] != '/',
-                "Cannot handle slash-terminated prefix pathes");
+                "Cannot handle slash-terminated prefix paths");
         
     sal_Bool bIsPrefix;
     if (_sNestedPath.getLength() > nPrefixLength)

Modified: openoffice/trunk/main/unotools/source/config/dynamicmenuoptions.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/unotools/source/config/dynamicmenuoptions.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================